package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Apr 5, 2025
License: AGPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
wheel contains code that reinvents the wheel.
func RandomIn[T any](a []T) T
RandomIn returns a random element from a slice.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.